@@ -5,12 +5,14 @@ use crate::Policy;
 /// Creates a policy to run futures concurrently.
 ///
 /// If one of the futures completes immediately no next futures will be run.
+///
+/// Note: this policy has no stop condition, so for getting a result you should wrap it with [attempts](`super::attempts`), [cond](`super::cond`) or your own wrapper.
 /// ## Example
 /// Sends at most 4 concurrent requests and waits for one with an [`Ok`] result.
 ///
 /// ```
 /// # async fn run() -> Result<(), reqwest::Error> {
-/// use fure::policies::{parallel, attempts};
+/// use fure::policies::{concurrent, attempts};
 ///
 /// let get_body = || async {
 ///     reqwest::get("https://www.rust-lang.org")
@@ -18,20 +20,20 @@ use crate::Policy;
 ///         .text()
 ///         .await
 /// };
-/// let body = fure::retry(get_body, attempts(parallel(), 3)).await?;
+/// let body = fure::retry(get_body, attempts(concurrent(), 3)).await?;
 /// println!("body = {}", body);
 /// # Ok(())
 /// # }
 /// ```
-pub fn parallel() -> ParallelRetryPolicy {
-    ParallelRetryPolicy
+pub fn concurrent() -> ConcurrentRetryPolicy {
+    ConcurrentRetryPolicy
 }
 
-/// A policy is created by [`parallel`] function.
+/// A policy is created by [`concurrent`] function.
 #[derive(Debug, Clone, Copy)]
-pub struct ParallelRetryPolicy;
+pub struct ConcurrentRetryPolicy;
 
-impl<T, E> Policy<T, E> for ParallelRetryPolicy {
+impl<T, E> Policy<T, E> for ConcurrentRetryPolicy {
     type ForceRetryFuture = Ready<()>;
     type RetryFuture = Ready<Self>;
 
@@ -44,19 +46,23 @@ impl<T, E> Policy<T, E> for ParallelRetryPolicy {
     }
 }
 #[cfg(any(feature = "tokio", feature = "async-std"))]
-mod delayed {
+mod _interval {
     use super::*;
     use std::time::Duration;
 
-    /// Creates a policy to run additional future after `force_retry_after` has passed without a result.
+    /// Creates a policy to concurrently run additional future after `force_retry_after` has passed without a result from previous future.
     ///
     /// After each completed future the previous delay is dropped and a new one is started.
+    ///
+    /// Note: this policy has no stop condition, so for getting a result you should wrap it with [attempts](`super::super::attempts`), [cond](`super::super::cond`) or your own wrapper.
     /// ## Example
-    /// Sends at most 4 concurrent requests and waits for one with an [`Ok`] result.
+    /// Starts with sending a request, setting up a 1 second timer and waits for either of them.
     ///
-    /// Every next future will be run only after 1 second.
+    /// If the timer completes first (it means that the request didn't complete in 1 second) one more request fires.
     ///
-    /// If request takes less than 1 second no next futures will be run.
+    /// If the request completes first and it has an [`Ok`] response it is returned, if request has an [`Err`] response, timer resets and a new request fires.
+    ///
+    /// At most 4 requests will be fired.
     /// ```
     /// # async fn run() -> Result<(), reqwest::Error> {
     /// use fure::policies::{interval, attempts};
@@ -68,7 +74,7 @@ mod delayed {
     ///         .text()
     ///         .await
     /// };
-    /// let body = fure::retry(get_body, attempts(interval(Duration::from_secs(1)), 4)).await?;
+    /// let body = fure::retry(get_body, attempts(interval(Duration::from_secs(1)), 3)).await?;
     /// println!("body = {}", body);
     /// # Ok(())
     /// # }
@@ -78,6 +84,7 @@ mod delayed {
     }
 
     /// A policy is created by [`interval`] function.
+    #[derive(Debug, Clone, Copy)]
     pub struct IntervalRetryPolicy {
         force_retry_after: Duration,
     }
@@ -96,7 +103,7 @@ mod delayed {
     }
 }
 #[cfg(any(feature = "tokio", feature = "async-std"))]
-pub use delayed::*;
+pub use _interval::*;
 
 #[cfg(test)]
 mod test {
@@ -109,7 +116,7 @@ mod test {
 
     mod concurrent {
 
-        use crate::policies::concurrent::parallel;
+        use crate::policies::concurrent::concurrent;
 
         use super::*;
 
@@ -136,7 +143,7 @@ mod test {
                     }
                 };
 
-                let result = retry(create_fut, attempts(parallel(), 4)).await;
+                let result = retry(create_fut, attempts(concurrent(), 4)).await;
 
                 let guard = call_count.lock().unwrap();
                 assert_eq!(*guard, 4);
@@ -161,7 +168,7 @@ mod test {
                     }
                 };
 
-                let result = retry(create_fut, attempts(parallel(), 5)).await;
+                let result = retry(create_fut, attempts(concurrent(), 5)).await;
 
                 let guard = call_count.lock().unwrap();
                 assert_eq!(*guard, 2);
